==> value-2.8.0-sources.jar: org/immutables/value/internal/$processor$/$Generator_CriteriaRepository.java <==
package org.immutables.value.processor;

import static org.immutables.generator.Intrinsics.*;

@java.lang.SuppressWarnings("all")
public class Generator_CriteriaRepository extends org.immutables.value.processor.CriteriaRepository {
public org.immutables.generator.Templates.Invokable generate() { return generate; }
private final org.immutables.generator.Templates.Invokable generate = new FragmentDispatch(0, 0);
void _t0__generate(org.immutables.generator.Templates.Invokation __) {
  __.dl();__.ln();
  __.out("  ");
  {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
  for (final org.immutables.value.processor.meta.ValueType type : $in(values.values())) {
  if ($if(type.isGenerateRepository())) {
  __.dl();__.ln();
    __.out("    ");
    __.dl();
    if ($if($(type.kind().isValue(), andnot, type.generics()))) {
      __.dl();__.ln();
      $(__, output.java, type.$$package(), $(type.name(), "Repository"), type.element, new org.immutables.generator.Templates.Fragment(0) {
      @Override public void run(org.immutables.generator.Templates.Invokation __) {
        __.dl();__.ln();
        $(__, type.sourceHeader());
        __.ln();
        $(__, generateRepository, type);
        __.ln();
        __.dl();
      }});
      __.ln();
      __.out("    ");
      
    } else {
      __.dl();__.ln();
      $(__, output.error, new org.immutables.generator.Templates.Fragment(0) {
      @Override public void run(org.immutables.generator.Templates.Invokation __) {
        __.dl();__.ln();
        __.out("Use @Criteria.Repository to annotate @Value.Immutable abstract value types with no type variables").ln();
        __.dl();
      }});
      __.ln();
      __.out("    ");
      
    }
    __.dl();__.ln();
    __.out("  ");
    __.dl();_it1.index++;
    _it1.first = false;
  }}}
  __.dl();__.ln();
  __.dl();
};

org.immutables.generator.Templates.Invokable generateRepository() { return generateRepository; }
private final org.immutables.generator.Templates.Invokable generateRepository = new FragmentDispatch(1, 1);
void _t1__generateRepository(org.immutables.generator.Templates.Invokation __) {
  __.dl();final org.immutables.value.processor.meta.ValueType type = $cast(__.param(0));
  __.ln();
  __.dl();
  if ($if(type.$$package())) {
    __.dl();__.ln();
    __.out("package ");
    $(__, type.$$package());
    __.out(";").ln();
    
  }
  __.dl();__.ln();
  __.ln();
  {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
  for (final java.lang.String starImport : $in(type.getRequiredSourceStarImports())) {
  __.dl();__.ln();
    __.out("import ");
    $(__, starImport);
    __.out(";").ln();
    __.dl();_it1.index++;
    _it1.first = false;
  }}
  __.dl();__.ln();
  __.ln();
  __.out("import com.google.common.collect.ImmutableList;").ln();
  __.ln();
  __.out("import org.immutables.criteria.Criterion;").ln();
  __.out("import org.immutables.criteria.Criterias;").ln();
  __.out("import org.immutables.criteria.backend.Backend;").ln();
  __.out("import org.immutables.criteria.backend.StandardOperations;").ln();
  __.out("import org.immutables.criteria.backend.WriteResult;").ln();
  __.out("import org.immutables.criteria.repository.Repository;").ln();
  __.out("import org.immutables.criteria.repository.Watcher;").ln();
  __.out("import org.immutables.criteria.repository.reactive.ReactiveRepository;").ln();
  __.out("import org.immutables.criteria.repository.reactive.ReactiveReader;").ln();
  __.out("import org.immutables.criteria.repository.reactive.ReactiveWatcher;").ln();
  __.ln();
  __.out("import org.reactivestreams.Publisher;").ln();
  __.ln();
  __.out("import java.util.Objects;").ln();
  __.out("import java.util.List;").ln();
  __.out("import java.util.function.Function;").ln();
  __.ln();
  __.out("/**").ln();
  __.out(" * A {@code ");
  $(__, type.name());
  __.out("Repository} provides access for storing and retrieving objects").ln();
  __.out(" * from a generic data-source based on {@link ");
  $(__, type.name());
  __.out("Criteria}.").ln();
  __.out(" */").ln();
  __.dl();
  if ($if($(type, allowsClasspathAnnotation, "javax.annotation.concurrent.ThreadSafe"))) {
    __.dl();__.ln();
    __.out("@javax.annotation.concurrent.ThreadSafe").ln();
    
  }
  __.dl();__.ln();
  $(__, type.typeDocument().access());
  __.out("class ");
  $(__, type.name());
  __.out("Repository implements Repository<");
  $(__, type.typeDocument());
  __.out(">");
  $(__, output.trim, new org.immutables.generator.Templates.Fragment(0) {
  @Override public void run(org.immutables.generator.Templates.Invokation __) {
    __.dl();__.ln();
    {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
    for (final org.immutables.value.processor.meta.RepositoryModel.Facet facet : $in(type.getCriteriaRepository().facets())) {
    __.dl();__.out(", ");
      $(__, facet.interfaceType());
      __.dl();_it1.index++;
      _it1.first = false;
    }}
    __.dl();__.out(" {");
    __.dl();
  }});
  __.ln();
  __.ln();
  __.out("  private final Backend backend;").ln();
  __.ln();
  __.out("  ");
  {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
  for (final org.immutables.value.processor.meta.RepositoryModel.Facet facet : $in(type.getCriteriaRepository().facets())) {
  __.dl();__.ln();
    __.out("  private final ");
    $(__, facet.fieldType());
    __.out(" ");
    $(__, facet.name());
    __.out(";").ln();
    __.out("  ");
    __.dl();_it1.index++;
    _it1.first = false;
  }}
  __.dl();__.ln();
  __.ln();
  __.out("  public ");
  $(__, type.name());
  __.out("Repository(Backend backend) {").ln();
  __.out("    this.backend = Objects.requireNonNull(backend, \"backend\");").ln();
  __.out("    ");
  __.dl();
  if ($if($(not, type.getCriteriaRepository().facets().isEmpty()))) {
    __.dl();__.ln();
    __.out("    ");
    __.dl();__.ln();
    __.out("    final Backend.Session session = backend.open(");
    $(__, type.typeDocument());
    __.out(".class);").ln();
    __.out("    ");
    
  }
  __.dl();__.ln();
  __.out("    ");
  {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
  for (final org.immutables.value.processor.meta.RepositoryModel.Facet facet : $in(type.getCriteriaRepository().facets())) {
  __.dl();__.ln();
    __.out("    ");
    __.dl();
    if ($if($(not, facet.constructor().isEmpty()))) {
      __.dl();__.ln();
      __.out("    ");
      $(__, facet.constructor().code);
      __.out(";").ln();
      __.out("    ");
      
    }
    __.dl();__.ln();
    __.out("    ");
    __.dl();_it1.index++;
    _it1.first = false;
  }}
  __.dl();__.ln();
  __.out("  }").ln();
  {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
  for (final org.immutables.value.processor.meta.RepositoryModel.Facet facet : $in(type.getCriteriaRepository().facets())) {
  __.dl();__.ln();
    {final org.immutables.generator.Templates.Iteration _it2 = new org.immutables.generator.Templates.Iteration();
    for (final org.immutables.value.processor.meta.RepositoryModel.DelegateMethod method : $in(facet.methods())) {
    __.dl();__.ln();
      __.ln();
      __.out("  @Override").ln();
      __.out("  public ");
      $(__, method.returnType());
      __.out(" ");
      $(__, method.name());
      __.out("(");
      $(__, method.parameters());
      __.out(") {").ln();
      __.out("     ");
      $(__, method.body());
      __.ln();
      __.out("  }").ln();
      __.dl();_it2.index++;
      _it2.first = false;
    }}
    __.dl();__.ln();
    __.dl();_it1.index++;
    _it1.first = false;
  }}
  __.dl();__.ln();
  __.out("}").ln();
  __.dl();
};
private class FragmentDispatch extends org.immutables.generator.Templates.Fragment{
private final int index;
FragmentDispatch(int arity, int index){
super(arity);
this.index = index;
}
@Override public void run(org.immutables.generator.Templates.Invokation invokation){
  switch (index){
  case 0: _t0__generate(invokation); break;
  case 1: _t1__generateRepository(invokation); break;
  default: break;
}}}

}

==> value-2.8.1-sources.jar: org/immutables/value/internal/$processor$/$Generator_CriteriaRepository.java <==
package org.immutables.value.processor;

import static org.immutables.generator.Intrinsics.*;

@java.lang.SuppressWarnings("all")
public class Generator_CriteriaRepository extends org.immutables.value.processor.CriteriaRepository {
public org.immutables.generator.Templates.Invokable generate() { return generate; }
private final org.immutables.generator.Templates.Invokable generate = new FragmentDispatch(0, 0);
void _t0__generate(org.immutables.generator.Templates.Invokation __) {
  __.dl();__.ln();
  __.out("  ");
  {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
  for (final org.immutables.value.processor.meta.ValueType type : $in(values.values())) {
  if ($if(type.isGenerateCriteriaRepository())) {
  __.dl();__.ln();
    __.out("    ");
    __.dl();
    if ($if($(type.kind().isValue(), or, type.kind().isJavaBean()))) {
      __.dl();__.ln();
      $(__, output.java, type.$$package(), $(type.name(), "Repository"), type.element, new org.immutables.generator.Templates.Fragment(0) {
      @Override public void run(org.immutables.generator.Templates.Invokation __) {
        __.dl();__.ln();
        $(__, type.sourceHeader());
        __.ln();
        $(__, generateRepository, type);
        __.ln();
        __.dl();
      }});
      __.ln();
      __.out("    ");
      
    } else {
      __.dl();__.ln();
      $(__, output.error, new org.immutables.generator.Templates.Fragment(0) {
      @Override public void run(org.immutables.generator.Templates.Invokation __) {
        __.dl();__.ln();
        __.out("Use @Criteria.Repository to annotate @Value.Immutable abstract value types with no type variables").ln();
        __.dl();
      }});
      __.ln();
      __.out("    ");
      
    }
    __.dl();__.ln();
    __.out("  ");
    __.dl();_it1.index++;
    _it1.first = false;
  }}}
  __.dl();__.ln();
  __.dl();
};

org.immutables.generator.Templates.Invokable generateRepository() { return generateRepository; }
private final org.immutables.generator.Templates.Invokable generateRepository = new FragmentDispatch(1, 1);
void _t1__generateRepository(org.immutables.generator.Templates.Invokation __) {
  __.dl();final org.immutables.value.processor.meta.ValueType type = $cast(__.param(0));
  __.ln();
  __.dl();
  if ($if(type.$$package())) {
    __.dl();__.ln();
    __.out("package ");
    $(__, type.$$package());
    __.out(";").ln();
    
  }
  __.dl();__.ln();
  __.ln();
  {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
  for (final java.lang.String starImport : $in(type.getRequiredSourceStarImports())) {
  __.dl();__.ln();
    __.out("import ");
    $(__, starImport);
    __.out(";").ln();
    __.dl();_it1.index++;
    _it1.first = false;
  }}
  __.dl();__.ln();
  __.ln();
  __.out("import com.google.common.collect.ImmutableList;").ln();
  __.ln();
  __.out("import org.immutables.criteria.Criterion;").ln();
  __.out("import org.immutables.criteria.Criterias;").ln();
  __.out("import org.immutables.criteria.backend.Backend;").ln();
  __.out("import org.immutables.criteria.backend.StandardOperations;").ln();
  __.out("import org.immutables.criteria.backend.WriteResult;").ln();
  __.out("import org.immutables.criteria.repository.Repository;").ln();
  __.out("import org.immutables.criteria.repository.Watcher;").ln();
  __.out("import org.immutables.criteria.repository.reactive.ReactiveRepository;").ln();
  __.out("import org.immutables.criteria.repository.reactive.ReactiveReader;").ln();
  __.out("import org.immutables.criteria.repository.reactive.ReactiveWatcher;").ln();
  __.ln();
  __.out("import org.reactivestreams.Publisher;").ln();
  __.ln();
  __.out("import java.util.Objects;").ln();
  __.out("import java.util.List;").ln();
  __.out("import java.util.function.Function;").ln();
  __.ln();
  __.out("/**").ln();
  __.out(" * A {@code ");
  $(__, type.name());
  __.out("Repository} provides access for storing and retrieving objects").ln();
  __.out(" * from a generic data-source based on {@link ");
  $(__, type.name());
  __.out("Criteria}.").ln();
  __.out(" */").ln();
  __.dl();
  if ($if($(type, allowsClasspathAnnotation, "javax.annotation.concurrent.ThreadSafe"))) {
    __.dl();__.ln();
    __.out("@javax.annotation.concurrent.ThreadSafe").ln();
    
  }
  __.dl();__.ln();
  $(__, type.typeDocument().access());
  __.out("class ");
  $(__, type.name());
  __.out("Repository implements Repository<");
  $(__, type.typeDocument());
  __.out(">");
  $(__, output.trim, new org.immutables.generator.Templates.Fragment(0) {
  @Override public void run(org.immutables.generator.Templates.Invokation __) {
    __.dl();__.ln();
    {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
    for (final org.immutables.value.processor.meta.RepositoryModel.Facet facet : $in(type.getCriteriaRepository().facets())) {
    __.dl();__.out(", ");
      $(__, facet.interfaceType());
      __.dl();_it1.index++;
      _it1.first = false;
    }}
    __.dl();__.out(" {");
    __.dl();
  }});
  __.ln();
  __.ln();
  __.out("  private final Backend backend;").ln();
  __.ln();
  __.out("  ");
  {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
  for (final org.immutables.value.processor.meta.RepositoryModel.Facet facet : $in(type.getCriteriaRepository().facets())) {
  __.dl();__.ln();
    __.out("  private final ");
    $(__, facet.fieldType());
    __.out(" ");
    $(__, facet.name());
    __.out(";").ln();
    __.out("  ");
    __.dl();_it1.index++;
    _it1.first = false;
  }}
  __.dl();__.ln();
  __.ln();
  __.out("  public ");
  $(__, type.name());
  __.out("Repository(Backend backend) {").ln();
  __.out("    this.backend = Objects.requireNonNull(backend, \"backend\");").ln();
  __.out("    ");
  __.dl();
  if ($if($(not, type.getCriteriaRepository().facets().isEmpty()))) {
    __.dl();__.ln();
    __.out("    ");
    __.dl();__.ln();
    __.out("    final Backend.Session session = backend.open(");
    $(__, type.typeDocument());
    __.out(".class);").ln();
    __.out("    ");
    
  }
  __.dl();__.ln();
  __.out("    ");
  {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
  for (final org.immutables.value.processor.meta.RepositoryModel.Facet facet : $in(type.getCriteriaRepository().facets())) {
  __.dl();__.ln();
    __.out("    ");
    __.dl();
    if ($if($(not, facet.constructor().isEmpty()))) {
      __.dl();__.ln();
      __.out("    ");
      $(__, facet.constructor().code);
      __.out(";").ln();
      __.out("    ");
      
    }
    __.dl();__.ln();
    __.out("    ");
    __.dl();_it1.index++;
    _it1.first = false;
  }}
  __.dl();__.ln();
  __.out("  }").ln();
  {final org.immutables.generator.Templates.Iteration _it1 = new org.immutables.generator.Templates.Iteration();
  for (final org.immutables.value.processor.meta.RepositoryModel.Facet facet : $in(type.getCriteriaRepository().facets())) {
  __.dl();__.ln();
    {final org.immutables.generator.Templates.Iteration _it2 = new org.immutables.generator.Templates.Iteration();
    for (final org.immutables.value.processor.meta.RepositoryModel.DelegateMethod method : $in(facet.methods())) {
    __.dl();__.ln();
      __.ln();
      __.out("  @Override").ln();
      __.out("  public ");
      $(__, method.returnType());
      __.out(" ");
      $(__, method.name());
      __.out("(");
      $(__, method.parameters());
      __.out(") {").ln();
      __.out("     ");
      $(__, method.body());
      __.ln();
      __.out("  }").ln();
      __.dl();_it2.index++;
      _it2.first = false;
    }}
    __.dl();__.ln();
    __.dl();_it1.index++;
    _it1.first = false;
  }}
  __.dl();__.ln();
  __.out("}").ln();
  __.dl();
};
private class FragmentDispatch extends org.immutables.generator.Templates.Fragment{
private final int index;
FragmentDispatch(int arity, int index){
super(arity);
this.index = index;
}
@Override public void run(org.immutables.generator.Templates.Invokation invokation){
  switch (index){
  case 0: _t0__generate(invokation); break;
  case 1: _t1__generateRepository(invokation); break;
  default: break;
}}}

}
